==> acra-core-5.4.0-sources.jar: org/acra/sender/ReportSender.java <==
/*
 *  Copyright 2010 Kevin Gaudin
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.acra.sender;

import android.content.Context;
import android.support.annotation.NonNull;

import org.acra.data.CrashReportData;

/**
 * A simple interface for defining various crash report senders.
 *
 * @author Kevin Gaudin
 */
public interface ReportSender {

    /**
     * Send crash report data.
     * <p>
     * Method will be called from the {@link LegacySenderService}.
     *
     * @param context      Android Context in which to send the crash report.
     * @param errorContent Stores key/value pairs for each report field.
     * @throws ReportSenderException If anything goes fatally wrong during the handling of crash data, you can (should) throw a {@link ReportSenderException} with a custom message.
     */
    void send(@NonNull Context context, @NonNull CrashReportData errorContent) throws ReportSenderException;

    default boolean requiresForeground() {
        return false;
    }
}

==> acra-core-5.6.1-sources.jar: org/acra/sender/ReportSender.java <==
/*
 *  Copyright 2010 Kevin Gaudin
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.acra.sender;

import android.content.Context;
import androidx.annotation.NonNull;

import org.acra.data.CrashReportData;
import org.acra.util.BundleWrapper;

/**
 * A simple interface for defining various crash report senders.
 *
 * @author Kevin Gaudin
 */
public interface ReportSender {

    /**
     * Send crash report data.
     * <p>
     * Method will be called from the {@link LegacySenderService}.
     *
     * @param context      Android Context in which to send the crash report.
     * @param errorContent Stores key/value pairs for each report field.
     * @throws ReportSenderException If anything goes fatally wrong during the handling of crash data, you can (should) throw a {@link ReportSenderException} with a custom message.
     */
    default void send(@NonNull Context context, @NonNull CrashReportData errorContent) throws ReportSenderException {
    }

    /**
     * Send crash report data.
     * <p>
     * Method will be called from the {@link LegacySenderService}.
     *
     * @param context      Android Context in which to send the crash report.
     * @param errorContent Stores key/value pairs for each report field.
     * @param extras       additional information set in a {@link org.acra.scheduler.DefaultSenderScheduler}
     * @throws ReportSenderException If anything goes fatally wrong during the handling of crash data, you can (should) throw a {@link ReportSenderException} with a custom message.
     */
    default void send(@NonNull Context context, @NonNull CrashReportData errorContent, @NonNull BundleWrapper extras) throws ReportSenderException {
        send(context, errorContent);
    }

    default boolean requiresForeground() {
        return false;
    }
}
